@@ -2,20 +2,7 @@ import os
 import pymssql
 from typing import Dict, List
 from collections import Counter
-
-PWD = os.getcwd()
-SOURCE_TABLES_PATH = os.path.join(PWD, 'sourceTables')
-SPARKSQL_TABLES_PATH = os.path.join(PWD, 'sparkTables')
-CTL_SELECT_PATH = os.path.join(PWD, 'ctlSelectS')
-if not os.path.exists(SOURCE_TABLES_PATH):
-    print(f"creating dir {SOURCE_TABLES_PATH}")
-    os.mkdir(SOURCE_TABLES_PATH)
-if not os.path.exists(SPARKSQL_TABLES_PATH):
-    os.mkdir(SPARKSQL_TABLES_PATH)
-    print(f"creating dir {SPARKSQL_TABLES_PATH}")
-if not os.path.exists(CTL_SELECT_PATH):
-    os.mkdir(CTL_SELECT_PATH)
-    print(f"creating dir {CTL_SELECT_PATH}")
+from .config import SOURCE_TABLES_PATH, SPARKSQL_TABLES_PATH, CTL_SELECT_PATH
 
 
 class Utils:
@@ -220,4 +207,3 @@ drop table if exists {db_tmp}.{table_name};
             }
             sql = self.create_spark_sql(args)
             self.save_spark_sql(table_name.lower(), sql)
-
